@@ -69,6 +69,13 @@ def camelize(snake_name: Optional[str]) -> Optional[str]:
     return "".join([parts[0]] + [w.title() for w in parts[1:]])
 
 
+def bool_query_param(val: bool) -> Optional[str]:
+    """
+    Serialize a bool to an API query parameter (e.g. True -> "true")
+    """
+    return str(val).lower() if val is not None else None
+
+
 class FoxgloveException(Exception):
     pass
 
@@ -401,8 +408,6 @@ class Client:
         return {
             "id": device["id"],
             "name": device["name"],
-            "created_at": arrow.get(device["createdAt"]).datetime,
-            "updated_at": arrow.get(device["updatedAt"]).datetime,
         }
 
     def get_devices(self):
@@ -420,8 +425,6 @@ class Client:
             {
                 "id": d["id"],
                 "name": d["name"],
-                "created_at": arrow.get(d["createdAt"]).datetime,
-                "updated_at": arrow.get(d["updatedAt"]).datetime,
             }
             for d in json
         ]
@@ -515,7 +518,7 @@ class Client:
             "end": end.astimezone().isoformat() if end else None,
             "dataStart": data_start.astimezone().isoformat() if data_start else None,
             "dataEnd": data_end.astimezone().isoformat() if data_end else None,
-            "includeDeleted": include_deleted,
+            "includeDeleted": bool_query_param(include_deleted),
             "filename": filename,
             "sortBy": camelize(sort_by),
             "sortOrder": sort_order,
@@ -536,7 +539,6 @@ class Client:
                 "import_time": arrow.get(i["importTime"]).datetime,
                 "start": arrow.get(i["start"]).datetime,
                 "end": arrow.get(i["end"]).datetime,
-                "metadata": i["metadata"],
                 "input_type": i["inputType"],
                 "output_type": i["outputType"],
                 "filename": i["filename"],
